;; Generated package description from gtags-mode.el  -*- no-byte-compile: t -*-
(define-package "gtags-mode" "1.8.1" "GNU Global integration with xref, project and imenu." '((emacs "28")) :commit "bdf5442efd8e8fae4610b0a73daca6ee81a5b0c4" :keywords '("xref" "project" "imenu" "gtags" "global") :url "https://github.com/Ergus/gtags-mode")
